
# pyrunning

*Please refer to [`LICENSE`](./LICENSE) for license information.*

## Overview

A python library to run and live-log *OS commands*, *functions*, *scripts*, and *batch jobs* either immedietly, or to be queued for later execution.

**Warning**: This package is still in the Beta stage. It is not ready for production use. Please do not use for any critical software

## [PLEASE CLICK HERE](https://github.com/shivanandvp/pyrunning/index.html) for the full documentation